param(
[switch]$MofUpdate,
[switch]$IEFeatureOff,
[ValidateSet('Computer','Intranet','TrustedSites','Internet','RestrictedSites')]
[string[]]$ZoneAllowList,
[string[]]$SiteAllowList
)

Function CalculateZoneMask($zones)
{
    $zoneMask = 0
    ForEach($zone in $zones)
    {
        $zoneId = 0
        Switch($zone)
        {
            'Computer' { $zoneId = 0 }
            'Intranet' { $zoneId = 1 }
            'TrustedSites' { $zoneId = 2 }
            'Internet' { $zoneId = 3 }
            'RestrictedSites' { $zoneId = 4 }
        }
        $zoneMask = $zoneMask -bor ([math]::pow(2,$zoneId))
    }

    $zoneMask
}

        <#
        IE Site Discovery Enable/Disable script.

        .USAGE
            Powershell needs to be run elevated.
            To run this script by by-passing execution policy please use:
                powershell -ExecutionPolicy Bypass .\IETElemetrySetUp.ps1

            NOTE: This script will FORCE A LOGOFF when ENABLING the feature. After logoff, IE
                  will be ready to collect browsing information.

            Arguments:
                NO ARGUMENTS:   Enables feature for all users on the machine. Forces a logoff at
                                the end.
                -IEFeatureOff:  Disables feature for all users on the machine. Does not clean up
                                already recorded information.
                -MofUpdate:     To force mof file re-compilation. Will also re-enable feature in
                                case it is disabled and force logoff.
                -ZoneAllowList: Comma-separated list of zones for which this feature is enabled.
                                Allowed values: Computer, Intranet, TrustedSites, Internet, 
                                RestrictedSites.
                -SiteAllowList: Comma-separated list of domains for which this feature is 
                                enabled. 

            For additional information on the feature:
                http://technet.microsoft.com/en-us/library/dn833204.aspx


        .NOTES
            IE looks for a registry setting in the HKCU hive for recording browsing information.
            This script updates the registry entry for all SIDs in the HKEY_USERS hive in order
            to enable IE Site Discovery across all users on the machine.
        #>

Try
{
    $SystemInfo = Get-WMIObject -namespace root/cimv2/IETelemetry -query "Select * from IESystemInfo where systemKey = 'SystemKey'" -ea Stop
}
Catch [system.exception]
{
}
Finally
{
    Try
    {
        if($MofUpdate -or !$SystemInfo)
        {
            $path = Split-Path $MyInvocation.MyCommand.Path
            $empty = mofcomp.exe $path\IETelemetry.mof
            $SDDL = "A;;CCLCSWRPWP;;;AU"
            $security = Get-WmiObject -Namespace root/cimv2/IETelemetry -Class __SystemSecurity
            $converter = new-object system.management.ManagementClass Win32_SecurityDescriptorHelper
            $binarySD = @($null)
            $result = $security.PsBase.InvokeMethod("GetSD",$binarySD)
            $outsddl = $converter.BinarySDToSDDL($binarySD[0])
            $newSDDL = $outsddl.SDDL += "(" + $SDDL + ")"
            $WMIbinarySD = $converter.SDDLToBinarySD($newSDDL)
            $WMIconvertedPermissions = ,$WMIbinarySD.BinarySD
            $result = $security.PsBase.InvokeMethod("SetSD",$WMIconvertedPermissions)
            $versionstring = [System.Diagnostics.FileVersionInfo]::GetVersionInfo("C:\Windows\System32\mshtml.dll").FileVersion
            $split = $versionstring.split(".")
            $a = Get-WMIObject -namespace root/cimv2/IETelemetry -query "Select * from IESystemInfo where systemKey = 'SystemKey'"
            $a.IEVer = $split[0]
            $empty = $a.Put()
            echo "IETelemetry.mof Compiled" 
        }
        <#
            The below code updates the HKCU hive and can be used in cases where the main\local user of a
            machine has admin rights AND if the script is run by the user and not by a system account
            via SCCM.
        #>
        if(!$IEFeatureOff)
        {
            if (!(Test-Path 'HKU:\')) 
            {
                New-PSDrive -PSProvider Registry -Name HKU -Root HKEY_USERS
            }            
            Push-Location
            Get-ChildItem -Path HKU:\*\Software\Microsoft\Internet?Explorer -ErrorAction SilentlyContinue | ForEach-Object {
                $empty = New-Item -Path "$($_.PsPath)\WMITelemetry" -force
                Set-Location "$($_.PsPath)\WMITelemetry"
                Set-ItemProperty -Path . -Name Active -Value 1

                if($ZoneAllowList.Length -gt 0)
                {
                    Set-ItemProperty -Path . -Name ZoneAllowList -Value (CalculateZoneMask $ZoneAllowList) -Type DWord
                }

                if($SiteAllowList.Length -gt 0)
                {
                    Set-ItemProperty -Path . -Name SiteAllowList -Value $SiteAllowList -Type MultiString
                }
            }
            Pop-Location
            echo "Forcing logoff. IE will start recording to WMI after re-login"
            shutdown /l
        }
        else
        {
            <#
              Remove entry from current user's HKCU hive
            #>
            if ((Test-Path 'HKCU:\Software\Microsoft\Internet Explorer\WMITelemetry')) 
            {
                Set-Location 'HKCU:\Software\Microsoft\Internet Explorer\WMITelemetry'
                Set-ItemProperty -Path . -Name Active -Value 0
            }
            if (!(Test-Path 'HKU:\')) 
            {
                New-PSDrive -PSProvider Registry -Name HKU -Root HKEY_USERS
            }            
            <#
              Remove entry from all users in the HKEY_USERS hive
            #>
            Push-Location
            Get-ChildItem -Path 'HKU:\*\Software\Microsoft\Internet?Explorer\WMITelemetry' -ErrorAction SilentlyContinue | ForEach-Object {
                Set-Location "$($_.PsPath)"
                Set-ItemProperty -Path . -Name Active -Value 0
            }
            Pop-Location
            echo "IE will no longer record to WMI after logoff and re-login"
        }
    }
    Catch
    {
        write-host "Caught an exception:" -ForegroundColor Red
        write-host "Exception Type: $($_.Exception.GetType().FullName)" -ForegroundColor Red
        write-host "Exception Message: $($_.Exception.Message)" -ForegroundColor Red
    }
}

# SIG # Begin signature block
# MIIbzAYJKoZIhvcNAQcCoIIbvTCCG7kCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQULN9vg5/oBq96vMZSboZShaDH
# 9mCgghaMMIIEuzCCA6OgAwIBAgITMwAAAFrtL/TkIJk/OgAAAAAAWjANBgkqhkiG
# 9w0BAQUFADB3MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
# A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSEw
# HwYDVQQDExhNaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EwHhcNMTQwNTIzMTcxMzE1
# WhcNMTUwODIzMTcxMzE1WjCBqzELMAkGA1UEBhMCVVMxCzAJBgNVBAgTAldBMRAw
# DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
# DTALBgNVBAsTBE1PUFIxJzAlBgNVBAsTHm5DaXBoZXIgRFNFIEVTTjpCOEVDLTMw
# QTQtNzE0NDElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZTCC
# ASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALMhIt9q0L/7KcnVbHqJqY0T
# vJS16X0pZdp/9B+rDHlhZlRhlgfw1GBLMZsJr30obdCle4dfdqHSxinHljqjXxeM
# duC3lgcPx2JhtLaq9kYUKQMuJrAdSgjgfdNcMBKmm/a5Dj1TFmmdu2UnQsHoMjUO
# 9yn/3lsgTLsvaIQkD6uRxPPOKl5YRu2pRbRptlQmkRJi/W8O5M/53D/aKWkfSq7u
# wIJC64Jz6VFTEb/dqx1vsgpQeAuD7xsIsxtnb9MFfaEJn8J3iKCjWMFP/2fz3uzH
# 9TPcikUOlkYUKIccYLf1qlpATHC1acBGyNTo4sWQ3gtlNdRUgNLpnSBWr9TfzbkC
# AwEAAaOCAQkwggEFMB0GA1UdDgQWBBS+Z+AuAhuvCnINOh1/jJ1rImYR9zAfBgNV
# HSMEGDAWgBQjNPjZUkZwCu1A+3b7syuwwzWzDzBUBgNVHR8ETTBLMEmgR6BFhkNo
# dHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNyb3Nv
# ZnRUaW1lU3RhbXBQQ0EuY3JsMFgGCCsGAQUFBwEBBEwwSjBIBggrBgEFBQcwAoY8
# aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNyb3NvZnRUaW1l
# U3RhbXBQQ0EuY3J0MBMGA1UdJQQMMAoGCCsGAQUFBwMIMA0GCSqGSIb3DQEBBQUA
# A4IBAQAgU4KQrqZNTn4zScizrcTDfhXQEvIPJ4p/W78+VOpB6VQDKym63VSIu7n3
# 2c5T7RAWPclGcLQA0fI0XaejIiyqIuFrob8PDYfQHgIb73i2iSDQLKsLdDguphD/
# 2pGrLEA8JhWqrN7Cz0qTA81r4qSymRpdR0Tx3IIf5ki0pmmZwS7phyPqCNJp5mLf
# cfHrI78hZfmkV8STLdsWeBWqPqLkhfwXvsBPFduq8Ki6ESus+is1Fm5bc/4w0Pur
# k6DezULaNj+R9+A3jNkHrTsnu/9UIHfG/RHpGuZpsjMnqwWuWI+mqX9dEhFoDCyj
# MRYNviGrnPCuGnxA1daDFhXYKPvlMIIFGTCCBAGgAwIBAgITMwAAAC0x9k+3ovl1
# awAAAAAALTANBgkqhkiG9w0BAQUFADCBgTELMAkGA1UEBhMCVVMxEzARBgNVBAgT
# Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
# dCBDb3Jwb3JhdGlvbjErMCkGA1UEAxMiTWljcm9zb2Z0IFdpbmRvd3MgVmVyaWZp
# Y2F0aW9uIFBDQTAeFw0xNTAxMTQyMTE3NTVaFw0xNTA3MTQyMTE3NTVaMH8xCzAJ
# BgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25k
# MR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xDTALBgNVBAsTBE1PUFIx
# GjAYBgNVBAMTEU1pY3Jvc29mdCBXaW5kb3dzMIIBIjANBgkqhkiG9w0BAQEFAAOC
# AQ8AMIIBCgKCAQEAwUd5pPI07XaOyC5WBEkpRO1ZJKy0+QGAyb27Bi5v3IGJ4wVQ
# BjMrjQZVgw2ZbdX8dLtU6wT06AVY1I8AkSXOKbotn6dhIJkYaHA/0GQEgvf/f8lt
# mCvYwzvMWykBXLyHYi7KygxQTLnPgoVVRyZ+Z04/oliEgyE4GUcaI5aL1x+TiwIN
# 5Hdc4QKxfW7xx0ZhFsWUiuJXL2I+9UxyLDM+adPO0nIJBFMHeZxdusRDYKp6I9GD
# xFJME0XM9uonVubRqhSKJ5k6TcAxiYB8Ft1xW25tC8jRR5kasGF64pyh9WeM+s3p
# yC2vClRBRKwtbJwIln7f8hntLTN5BppsAF+IEwIDAQABo4IBiTCCAYUwHwYDVR0l
# BBgwFgYIKwYBBQUHAwMGCisGAQQBgjcKAwYwHQYDVR0OBBYEFBz8ay6UI/5BT7MT
# UWqtPUMl09uVMFEGA1UdEQRKMEikRjBEMQ0wCwYDVQQLEwRNT1BSMTMwMQYDVQQF
# EyozMTY0NCszNDJhMzk2Yy1mZTA2LTQyNGEtYmFmZC0yOGQ1MGJjMWUyMjcwHwYD
# VR0jBBgwFoAUkIsRpXDt4PmpwKwIx7X0grE8xUowewYDVR0fBHQwcjBwoG6gbIY0
# aHR0cDovL2NybC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMvV2luUENB
# LmNybIY0aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMv
# V2luUENBLmNybDBSBggrBgEFBQcBAQRGMEQwQgYIKwYBBQUHMAKGNmh0dHA6Ly93
# d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWljcm9zb2Z0V2luUENBLmNydDAN
# BgkqhkiG9w0BAQUFAAOCAQEAtXY6IyXJkaqFgsgGoZTx9QwDr+y4D0XcDCFFikA8
# a1+gXE7O6pvwGQlEEvgvjd26QzgizSb2zCjIBd8O27cNgyERtoxPGhjzpFRcXp99
# MzyhByq/Z3Y7WnaIfwhSkf2QRb5/sD/Dv7IqIK79vVF/vhQbcN5Xe4Oh26PTRlmb
# bktO1HVq/6cfnld4tzDfYaoDELYRE/p/NxjTZA1sU3Qh3GbmHPkjZqVRSUsujpNB
# 32LbNQbnSbmlX+zVvEdT78lYaCsEy6WBMK4e4TfX4Z0dA3hyq9/j9Upv7PSLrEOA
# 8sKgfpSPAmlqKxOUAIMDKHkUQ2FZKN22Yyp3PxfCldzJWTCCBgcwggPvoAMCAQIC
# CmEWaDQAAAAAABwwDQYJKoZIhvcNAQEFBQAwXzETMBEGCgmSJomT8ixkARkWA2Nv
# bTEZMBcGCgmSJomT8ixkARkWCW1pY3Jvc29mdDEtMCsGA1UEAxMkTWljcm9zb2Z0
# IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5MB4XDTA3MDQwMzEyNTMwOVoXDTIx
# MDQwMzEzMDMwOVowdzELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
# EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
# bjEhMB8GA1UEAxMYTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBMIIBIjANBgkqhkiG
# 9w0BAQEFAAOCAQ8AMIIBCgKCAQEAn6Fssd/bSJIqfGsuGeG94uPFmVEjUK3O3RhO
# JA/u0afRTK10MCAR6wfVVJUVSZQbQpKumFwwJtoAa+h7veyJBw/3DgSY8InMH8sz
# JIed8vRnHCz8e+eIHernTqOhwSNTyo36Rc8J0F6v0LBCBKL5pmyTZ9co3EZTsIbQ
# 5ShGLieshk9VUgzkAyz7apCQMG6H81kwnfp+1pez6CGXfvjSE/MIt1NtUrRFkJ9I
# AEpHZhEnKWaol+TTBoFKovmEpxFHFAmCn4TtVXj+AZodUAiFABAwRu233iNGu8Qt
# VJ+vHnhBMXfMm987g5OhYQK1HQ2x/PebsgHOIktU//kFw8IgCwIDAQABo4IBqzCC
# AacwDwYDVR0TAQH/BAUwAwEB/zAdBgNVHQ4EFgQUIzT42VJGcArtQPt2+7MrsMM1
# sw8wCwYDVR0PBAQDAgGGMBAGCSsGAQQBgjcVAQQDAgEAMIGYBgNVHSMEgZAwgY2A
# FA6sgmBAVieX5SUT/CrhClOVWeSkoWOkYTBfMRMwEQYKCZImiZPyLGQBGRYDY29t
# MRkwFwYKCZImiZPyLGQBGRYJbWljcm9zb2Z0MS0wKwYDVQQDEyRNaWNyb3NvZnQg
# Um9vdCBDZXJ0aWZpY2F0ZSBBdXRob3JpdHmCEHmtFqFKoKWtTHNY9AcTLmUwUAYD
# VR0fBEkwRzBFoEOgQYY/aHR0cDovL2NybC5taWNyb3NvZnQuY29tL3BraS9jcmwv
# cHJvZHVjdHMvbWljcm9zb2Z0cm9vdGNlcnQuY3JsMFQGCCsGAQUFBwEBBEgwRjBE
# BggrBgEFBQcwAoY4aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9N
# aWNyb3NvZnRSb290Q2VydC5jcnQwEwYDVR0lBAwwCgYIKwYBBQUHAwgwDQYJKoZI
# hvcNAQEFBQADggIBABCXisNcA0Q23em0rXfbznlRTQGxLnRxW20ME6vOvnuPuC7U
# EqKMbWK4VwLLTiATUJndekDiV7uvWJoc4R0Bhqy7ePKL0Ow7Ae7ivo8KBciNSOLw
# UxXdT6uS5OeNatWAweaU8gYvhQPpkSokInD79vzkeJkuDfcH4nC8GE6djmsKcpW4
# oTmcZy3FUQ7qYlw/FpiLID/iBxoy+cwxSnYxPStyC8jqcD3/hQoT38IKYY7w17gX
# 606Lf8U1K16jv+u8fQtCe9RTciHuMMq7eGVcWwEXChQO0toUmPU8uWZYsy0v5/mF
# hsxRVuidcJRsrDlM1PZ5v6oYemIp76KbKTQGdxpiyT0ebR+C8AvHLLvPQ7Pl+ex9
# teOkqHQ1uE7FcSMSJnYLPFKMcVpGQxS8s7OwTWfIn0L/gHkhgJ4VMGboQhJeGsie
# IiHQQ+kr6bv0SMws1NgygEwmKkgkX1rqVu+m3pmdyjpvvYEndAYR7nYhv5uCwSdU
# trFqPYmhdmG0bqETpr+qR/ASb/2KMmyy/t9RyIwjyWa9nR2HEmQCPS2vWY+45CHl
# tbDKY7R4VAXUQS5QrJSwpXirs6CWdRrZkocTdSIvMqgIbqBbjCW/oO+EyiHW6x5P
# yZruSeD3AWVviQt9yGnI5m7qp5fOMSn/DsVbXNhNG6HY+i+ePy5VFmvJE6P9MIIG
# oTCCBImgAwIBAgIKYQcC3AAAAAAACzANBgkqhkiG9w0BAQUFADBfMRMwEQYKCZIm
# iZPyLGQBGRYDY29tMRkwFwYKCZImiZPyLGQBGRYJbWljcm9zb2Z0MS0wKwYDVQQD
# EyRNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkwHhcNMDUwOTE1
# MjE1NTQxWhcNMTYwMzE1MjIwNTQxWjCBgTELMAkGA1UEBhMCVVMxEzARBgNVBAgT
# Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
# dCBDb3Jwb3JhdGlvbjErMCkGA1UEAxMiTWljcm9zb2Z0IFdpbmRvd3MgVmVyaWZp
# Y2F0aW9uIFBDQTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMWsk07m
# ShGeN9A10rAGXIMUpWGS/P6zicHmzcgfMYQJkTRGkiy47izFIHPE6BrYjc56aLVm
# eIvlYBWi9ilaHV5d/GLTwVwpifsz+BaVNt2xRnRpclPVquiKmRrY92cJ2QkgIjh6
# 1gMj14mfHAG3Ud+YZioCiwbs5CnvW0IXFZdRjX0lCq8l6N7cm2cWClZznbMdhYML
# fjMrYjPOHCCBS17Txkm49i7TTrBxREZkPt5DZgS5zINIOsU2egRIC4kCPWOiAXYp
# l3XpAeYAlwmS+OIn8ClnQ3fDUJZTMeG2cYvsd8d8MUjVuCUijAD3KDh6vXzHP81A
# JnfdAAARmpW+H9sCAwEAAaOCAjowggI2MBAGCSsGAQQBgjcVAQQDAgEAMB0GA1Ud
# DgQWBBSQixGlcO3g+anArAjHtfSCsTzFSjALBgNVHQ8EBAMCAcYwDwYDVR0TAQH/
# BAUwAwEB/zCBmAYDVR0jBIGQMIGNgBQOrIJgQFYnl+UlE/wq4QpTlVnkpKFjpGEw
# XzETMBEGCgmSJomT8ixkARkWA2NvbTEZMBcGCgmSJomT8ixkARkWCW1pY3Jvc29m
# dDEtMCsGA1UEAxMkTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5
# ghB5rRahSqClrUxzWPQHEy5lMFAGA1UdHwRJMEcwRaBDoEGGP2h0dHA6Ly9jcmwu
# bWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL21pY3Jvc29mdHJvb3RjZXJ0
# LmNybDBUBggrBgEFBQcBAQRIMEYwRAYIKwYBBQUHMAKGOGh0dHA6Ly93d3cubWlj
# cm9zb2Z0LmNvbS9wa2kvY2VydHMvTWljcm9zb2Z0Um9vdENlcnQuY3J0MIGABgNV
# HSAEeTB3MHUGCSsGAQQBgjcVLzBoMGYGCCsGAQUFBwICMFoeWABDAG8AcAB5AHIA
# aQBnAGgAdAAgAKkAIAAxADkAOQA5AC0AMgAwADAANQAgAE0AaQBjAHIAbwBzAG8A
# ZgB0ACAAQwBvAHIAcABvAHIAYQB0AGkAbwBuAC4wHwYDVR0lBBgwFgYIKwYBBQUH
# AwMGCisGAQQBgjcKAwYwDQYJKoZIhvcNAQEFBQADggIBACUxoVjqUuXhFwzm8T94
# oz9yr6dXEFOJEF4ynLZwwxUrTRUwNOjAauQc0y4gZUjXG5hiIbpFn0rs2y8JGVHl
# 7TIZUS/h3fvGUv3rxoIlQgMJpji2Nh/MyYC7WmkYMcOzoLNnR76dx+I/lrOI+Bm+
# Obnplc78fK+ozdBBkODVsxwvaLvbD2xq3fKv3vK13g22plrwhgq5bZlLP3stAYRs
# j4fcf4+rFIjQBpE0vhuCIqS8VYqtm/xzFBDEyRkeB32bDsCVJl3GH6y08n66JXBK
# e9eO0Z2gE0l6sAJSUiT0r91ALeU+MlizSmrdEVmqLbykoHM4+UB3azQZV804aCeC
# +NFv6yPAP1LzTtUCPmqaK8H1MXHbQU073u+trx+IZUMbUbeadcqOaUkQj3iKdEW5
# CY5zdwcySkvXaCuYxbpU6j/LogCMu9gQWPLb3JvN2OpIQ+JKfmWy3PUtTiVnqOC1
# uqfdfl7BTAJ0ybNu4/jwC+38uSnFW8k2UZDbeH25Mg9edtIVXDs3IcbbyRlu7XQq
# XCwLUUlFU7CysyPUobBfDRnNFKfjPJuXcpQU3//BkBul3/Wp8xsX2rX8RODo4jyi
# eru7ZeZNsbUVodlnO7AMfTvp7lEqR/UVD4ytXS413/SkLvYTN1or6FWaSSyXzp0B
# npdGXNktvCRalVlvTcqd1lcmMYIEqjCCBKYCAQEwgZkwgYExCzAJBgNVBAYTAlVT
# MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
# ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xKzApBgNVBAMTIk1pY3Jvc29mdCBXaW5k
# b3dzIFZlcmlmaWNhdGlvbiBQQ0ECEzMAAAAtMfZPt6L5dWsAAAAAAC0wCQYFKw4D
# AhoFAKCBujAZBgkqhkiG9w0BCQMxDAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgEL
# MQ4wDAYKKwYBBAGCNwIBFTAjBgkqhkiG9w0BCQQxFgQURCW9NGrCsG0V7kT3eoom
# AH98LhkwWgYKKwYBBAGCNwIBDDFMMEqgJIAiAE0AaQBjAHIAbwBzAG8AZgB0ACAA
# VwBpAG4AZABvAHcAc6EigCBodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vd2luZG93
# czANBgkqhkiG9w0BAQEFAASCAQB12psJeeVp8yRq9tuZuPYJW+2SbRh5zWs+QT31
# lE68a9qSBIBtfWJlRLrUv5CLmmDYsFt5QzFo2vjd7pt9UjflBtP02Hqp4sfoa1t7
# vgjK2k88cznz+aS/juCvb1yBbyyZOtIjwDpVXnl/Kc1OjgYALDSs92EpPrXjl2AA
# 0d28ym7iCbze+eNUB+ewKPAf7Bg41LUGVj7DTQNYfrqc4GDwium9XrK4b34HCxoj
# o8dFW8lVx4ScQeEo6yYnV2FMekKym84W5zCp9Rp+dO/M4p5akXtrQmWKVqVPiwm3
# F8k3H/PnSuge88GoDyUtjfALVc3cz/VyYPmI/dyr7KPBPORooYICKDCCAiQGCSqG
# SIb3DQEJBjGCAhUwggIRAgEBMIGOMHcxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpX
# YXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQg
# Q29ycG9yYXRpb24xITAfBgNVBAMTGE1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQQIT
# MwAAAFrtL/TkIJk/OgAAAAAAWjAJBgUrDgMCGgUAoF0wGAYJKoZIhvcNAQkDMQsG
# CSqGSIb3DQEHATAcBgkqhkiG9w0BCQUxDxcNMTUwMzExMjExNjQ2WjAjBgkqhkiG
# 9w0BCQQxFgQU5jrUAxTfMT9mwyNG3apUENzrgpUwDQYJKoZIhvcNAQEFBQAEggEA
# ffx4Viz6XNK/hM+qz0OSgrsV1vRrp8QyTJh+rfqjJORqinNHiGoJvsREKhMprwpI
# 3DjyFDHAZoOeMo2KPwctqsVmUEC/NMF5bct3+QoqdSTe9y368FA8q8HfpFwzMcDa
# BN0SJHwigLOjylAnVNJ731pQv9ujL1B1C5fwm5dbF7AamKH4GRLyirBpNJ63p1Wt
# hEBqUWc28YFqUzk8iRVJcwRzsarQWs5j2oZJc15z9/UIry/NjjabHwC6kmmKDwFT
# kBca2GcDOwzsNmmty6cQfTOQsDPeRrpPIjIGQ56ePt6+zBe0Iy/mcNyDjsdPRxU9
# Fhi7trwtTmZ93IsEUI0gaQ==
# SIG # End signature block
