param(
[switch]$MofUpdate,
[switch]$IEFeatureOff,
[ValidateSet('Computer','Intranet','TrustedSites','Internet','RestrictedSites')]
[string[]]$ZoneAllowList,
[string[]]$SiteAllowList
)

Function CalculateZoneMask($zones)
{
    $zoneMask = 0
    ForEach($zone in $zones)
    {
        $zoneId = 0
        Switch($zone)
        {
            'Computer' { $zoneId = 0 }
            'Intranet' { $zoneId = 1 }
            'TrustedSites' { $zoneId = 2 }
            'Internet' { $zoneId = 3 }
            'RestrictedSites' { $zoneId = 4 }
        }
        $zoneMask = $zoneMask -bor ([math]::pow(2,$zoneId))
    }

    $zoneMask
}

        <#
        IE Site Discovery Enable/Disable script.

        .USAGE
            Powershell needs to be run elevated.
            To run this script by by-passing execution policy please use:
                powershell -ExecutionPolicy Bypass .\IETElemetrySetUp.ps1

            NOTE: This script will FORCE A LOGOFF when ENABLING the feature. After logoff, IE
                  will be ready to collect browsing information.

            Arguments:
                NO ARGUMENTS:   Enables feature for all users on the machine. Forces a logoff at
                                the end.
                -IEFeatureOff:  Disables feature for all users on the machine. Does not clean up
                                already recorded information.
                -MofUpdate:     To force mof file re-compilation. Will also re-enable feature in
                                case it is disabled and force logoff.
                -ZoneAllowList: Comma-separated list of zones for which this feature is enabled.
                                Allowed values: Computer, Intranet, TrustedSites, Internet, 
                                RestrictedSites.
                -SiteAllowList: Comma-separated list of domains for which this feature is 
                                enabled. 

            For additional information on the feature:
                http://technet.microsoft.com/en-us/library/dn833204.aspx


        .NOTES
            IE looks for a registry setting in the HKCU hive for recording browsing information.
            This script updates the registry entry for all SIDs in the HKEY_USERS hive in order
            to enable IE Site Discovery across all users on the machine.
        #>

Try
{
    $SystemInfo = Get-WMIObject -namespace root/cimv2/IETelemetry -query "Select * from IESystemInfo where systemKey = 'SystemKey'" -ea Stop
}
Catch [system.exception]
{
}
Finally
{
    Try
    {
        if($MofUpdate -or !$SystemInfo)
        {
            $path = Split-Path $MyInvocation.MyCommand.Path
            $empty = mofcomp.exe $path\IETelemetry.mof
            $SDDL = "A;;CCLCSWRPWP;;;AU"
            $security = Get-WmiObject -Namespace root/cimv2/IETelemetry -Class __SystemSecurity
            $converter = new-object system.management.ManagementClass Win32_SecurityDescriptorHelper
            $binarySD = @($null)
            $result = $security.PsBase.InvokeMethod("GetSD",$binarySD)
            $outsddl = $converter.BinarySDToSDDL($binarySD[0])
            $newSDDL = $outsddl.SDDL += "(" + $SDDL + ")"
            $WMIbinarySD = $converter.SDDLToBinarySD($newSDDL)
            $WMIconvertedPermissions = ,$WMIbinarySD.BinarySD
            $result = $security.PsBase.InvokeMethod("SetSD",$WMIconvertedPermissions)
            $versionstring = [System.Diagnostics.FileVersionInfo]::GetVersionInfo("C:\Windows\System32\mshtml.dll").FileVersion
            $split = $versionstring.split(".")
            $a = Get-WMIObject -namespace root/cimv2/IETelemetry -query "Select * from IESystemInfo where systemKey = 'SystemKey'"
            $a.IEVer = $split[0]
            $empty = $a.Put()
            echo "IETelemetry.mof Compiled" 
        }
        <#
            The below code updates the HKCU hive and can be used in cases where the main\local user of a
            machine has admin rights AND if the script is run by the user and not by a system account
            via SCCM.
        #>
        if(!$IEFeatureOff)
        {
            if (!(Test-Path 'HKU:\')) 
            {
                New-PSDrive -PSProvider Registry -Name HKU -Root HKEY_USERS
            }            
            Push-Location
            Get-ChildItem -Path HKU:\*\Software\Microsoft\Internet?Explorer -ErrorAction SilentlyContinue | ForEach-Object {
                $empty = New-Item -Path "$($_.PsPath)\WMITelemetry" -force
                Set-Location "$($_.PsPath)\WMITelemetry"
                Set-ItemProperty -Path . -Name Active -Value 1

                if($ZoneAllowList.Length -gt 0)
                {
                    Set-ItemProperty -Path . -Name ZoneAllowList -Value (CalculateZoneMask $ZoneAllowList) -Type DWord
                }

                if($SiteAllowList.Length -gt 0)
                {
                    Set-ItemProperty -Path . -Name SiteAllowList -Value $SiteAllowList -Type MultiString
                }
            }
            Pop-Location
            echo "Forcing logoff. IE will start recording to WMI after re-login"
            shutdown /l
        }
        else
        {
            <#
              Remove entry from current user's HKCU hive
            #>
            if ((Test-Path 'HKCU:\Software\Microsoft\Internet Explorer\WMITelemetry')) 
            {
                Set-Location 'HKCU:\Software\Microsoft\Internet Explorer\WMITelemetry'
                Set-ItemProperty -Path . -Name Active -Value 0
            }
            if (!(Test-Path 'HKU:\')) 
            {
                New-PSDrive -PSProvider Registry -Name HKU -Root HKEY_USERS
            }            
            <#
              Remove entry from all users in the HKEY_USERS hive
            #>
            Push-Location
            Get-ChildItem -Path 'HKU:\*\Software\Microsoft\Internet?Explorer\WMITelemetry' -ErrorAction SilentlyContinue | ForEach-Object {
                Set-Location "$($_.PsPath)"
                Set-ItemProperty -Path . -Name Active -Value 0
            }
            Pop-Location
            echo "IE will no longer record to WMI after logoff and re-login"
        }
    }
    Catch
    {
        write-host "Caught an exception:" -ForegroundColor Red
        write-host "Exception Type: $($_.Exception.GetType().FullName)" -ForegroundColor Red
        write-host "Exception Message: $($_.Exception.Message)" -ForegroundColor Red
    }
}

# SIG # Begin signature block
# MIIh7QYJKoZIhvcNAQcCoIIh3jCCIdoCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCDe8fx4iD7TMx/p
# I/AxJ68GkZshk3HaFXbwYw8bqboWCKCCC4MwggULMIID86ADAgECAhMzAAAAe6KB
# C4cRq+f8AAAAAAB7MA0GCSqGSIb3DQEBCwUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTAwHhcNMTQxMDAxMTgwNjM4WhcNMTYwMTAxMTgwNjM4WjCBgzEL
# MAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
# bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjENMAsGA1UECxMETU9Q
# UjEeMBwGA1UEAxMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMIIBIjANBgkqhkiG9w0B
# AQEFAAOCAQ8AMIIBCgKCAQEAvQcxxth2EB1eNeHpmIf/xHv5hBJHStPFJ2Zp22w2
# nNOhA3CXNR09AyJfXIEL50eYNUaSPv035IjaKWFTJMd9iXVt9WcwDtqZ40mvXhVE
# IyRFFgVmHcDac0t+/HxA4SPZKYlGHAvdNz8gd97MD7tIaeAXcx/qOxYqkhsujIJJ
# OKAqkfCh2w/3fWqRLgVrimZlJghs5DJOT5DL6br8nBYxqgjIsp4c8QsCsBZdlXxK
# m+7DAolGOmGJ8GwTtg1m3hcURkrTyXnyx34N2x22kH5gItwtcNicDAMnN6xc8ydI
# WviJIaR0Gj4Da8UiqTd9s2dNxuScWaOIuy/Ev/9DUf1zPQIDAQABo4IBejCCAXYw
# HwYDVR0lBBgwFgYIKwYBBQUHAwMGCisGAQQBgjc9BgEwHQYDVR0OBBYEFE8LE+6Q
# o6azvj+qlES88piRTzIdMFEGA1UdEQRKMEikRjBEMQ0wCwYDVQQLEwRNT1BSMTMw
# MQYDVQQFEyozODA3Nis2OGQyZjhiYi0wYTNiLTQwYjQtOWYyNC1lYjdlOTQxOWQx
# NjAwHwYDVR0jBBgwFoAU5vxfe7siAFjkck619CF0IzLm76wwVgYDVR0fBE8wTTBL
# oEmgR4ZFaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMv
# TWljQ29kU2lnUENBXzIwMTAtMDctMDYuY3JsMFoGCCsGAQUFBwEBBE4wTDBKBggr
# BgEFBQcwAoY+aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWND
# b2RTaWdQQ0FfMjAxMC0wNy0wNi5jcnQwDAYDVR0TAQH/BAIwADANBgkqhkiG9w0B
# AQsFAAOCAQEAL1QbJw93iIl4XlutFtrDwEs8JT/kMaquI7SOYeIwgVH+SI71MCMZ
# TcveYIhzmIcEQz3gi+6gC28dVa6Y0GeuADG+vu3thnUKkko63nE4tGH3wDvhMRbx
# /L8wYXp13zaEV3R/HaYCiukoMfWMkN+qWdGepYUmp+PAXFTl3dVd/4oxMTdbLf4t
# lx1QqOyGSAyRrbJmPB57RWEJrGfhfYInTwr8Sy7UF/mVMxF7qCYBPJJD5pngvKsK
# TXNRW3YSyiaJ1TXHutME/dy4jipqbcZXUUA9qjRIICpPnoFxyk1VhBpKePeG96WJ
# MV0lBi+tzLVoWe5RSzxIKyI2qxzQho7SiTCCBnAwggRYoAMCAQICCmEMUkwAAAAA
# AAMwDQYJKoZIhvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
# aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
# cG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1
# dGhvcml0eSAyMDEwMB4XDTEwMDcwNjIwNDAxN1oXDTI1MDcwNjIwNTAxN1owfjEL
# MAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
# bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEoMCYGA1UEAxMfTWlj
# cm9zb2Z0IENvZGUgU2lnbmluZyBQQ0EgMjAxMDCCASIwDQYJKoZIhvcNAQEBBQAD
# ggEPADCCAQoCggEBAOkOZFB5Z7XE4/0JAEyelKz3VmjqRNjPxVhPqaV2fG1FutM5
# krSkHvn5ZYLkF9KP/UScCOhlk84sVYS/fQjjLiuoQSsYt6JLbklMaxUH3tHSwoke
# cZTNtX9LtK8I2MyI1msXlDqTziY/7Ob+NJhX1R1dSfayKi7VhbtZP/iQtCuDdMor
# sztG4/BGScEXZlTJHL0dxFViV3L4Z7klIDTeXaallV6rKIDN1bKe5QO1Y9OyFMjB
# yIomCll/B+z/Du2AEjVMEqa+Ulv1ptrgiwtId9aFR9UQucboqu6Lai0FXGDGtCpb
# nCMcX0XjGhQebzfLGTOAaolNo2pmY3iT1TDPlR8CAwEAAaOCAeMwggHfMBAGCSsG
# AQQBgjcVAQQDAgEAMB0GA1UdDgQWBBTm/F97uyIAWORyTrX0IXQjMubvrDAZBgkr
# BgEEAYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUw
# AwEB/zAfBgNVHSMEGDAWgBTV9lbLj+iiXGJo0T2UkFvXzpoYxDBWBgNVHR8ETzBN
# MEugSaBHhkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0
# cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcmwwWgYIKwYBBQUHAQEETjBMMEoG
# CCsGAQUFBzAChj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRzL01p
# Y1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNydDCBnQYDVR0gBIGVMIGSMIGPBgkrBgEE
# AYI3LgMwgYEwPQYIKwYBBQUHAgEWMWh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9Q
# S0kvZG9jcy9DUFMvZGVmYXVsdC5odG0wQAYIKwYBBQUHAgIwNB4yIB0ATABlAGcA
# YQBsAF8AUABvAGwAaQBjAHkAXwBTAHQAYQB0AGUAbQBlAG4AdAAuIB0wDQYJKoZI
# hvcNAQELBQADggIBABp071dPKXvEFoV4uFDTIvwJnayCl/g0/yosl5US5eS/z7+T
# yOM0qduBuNweAL7SNW+v5X95lXflAtTx69jNTh4bYaLCWiMa8IyoYlFFZwjjPzwe
# k/gwhRfIOUCm1w6zISnlpaFpjCKTzHSY56FHQ/JTrMAPMGl//tIlIG1vYdPfB9XZ
# cgAsaYZ2PVHbpjlIyTdhbQfdUxnLp9Zhwr/ig6sP4GubldZ9KFGwiUpRpJpsyLcf
# ShoOaanX3MF+0Ulwqratu3JHYxf6ptaipobsqBBEm2O2smmJBsdGhnoYP+jFHSHV
# e/kCIy3FQcu/HUzIFu+xnH/8IktJim4V46Z/dlvRU3mRhZ3V0ts9czXzPK5UslJH
# asCqE5XSjhHamWdeMoz7N4XR3HWFnIfGWleFwr/dDY+Mmy3rtO7PJ9O1Xmn6pBYE
# AackZ3PPTU+23gVWl3r36VJN9HcFT4XG2Avxju1CCdENduMjVngiJja+yrGMbqod
# 5IXaRzNij6TJkTNfcR5Ar5hlySLoQiElihwtYNk3iUGJKhYP12E8lGhgUu/WR5mg
# gEDuFYF3PpzgUxgaUB04lZseZjMTJzkXeIc2zk7DX7L1PUdTtuDl2wthPSrXkizO
# N1o+QEIxpB8QCMJWnL8kXVECnWp50hfT2sGUjgd7JXFEqwZq5tTG3yOalnXFMYIV
# wDCCFbwCAQEwgZUwfjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
# EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
# bjEoMCYGA1UEAxMfTWljcm9zb2Z0IENvZGUgU2lnbmluZyBQQ0EgMjAxMAITMwAA
# AHuigQuHEavn/AAAAAAAezANBglghkgBZQMEAgEFAKCBxjAZBgkqhkiG9w0BCQMx
# DAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAvBgkq
# hkiG9w0BCQQxIgQg0CdarkudPmS135KP5OXAbCCX8qol8GqEFuF2iYMB5OYwWgYK
# KwYBBAGCNwIBDDFMMEqgJIAiAE0AaQBjAHIAbwBzAG8AZgB0ACAAVwBpAG4AZABv
# AHcAc6EigCBodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vd2luZG93czANBgkqhkiG
# 9w0BAQEFAASCAQBsSeMmUES6ZFGCKNs6lmsNp3zwkR6XWFUZNqz+25WVYObZQdwi
# sTX+A1/s0ICGUpI0doHRoXJCKDWQ/QwgJsMEKIVcgY1lXdBAnZw4DJYi/uXBMBrs
# ef3j3Gfi7Fv3u1l0RKdyxnsMzArURh7tSRIP2icM22J2EB63d+1pOCeJxVyJdqNA
# lkXRsLAoBH41p+Km0fWwvKyqIOLumwbEYQNgs7oxZhwW2oGIZQoFiqU7qwFLDXwr
# xOS8NsktwQrDucNznNw3cbcpFNHEmzvgT0YQE2MmzPKGtSgB8RzH7tyzVtFFRp4m
# nc6O0Kk6IyXWumFGnwAk97VxFqeZ79cLcdbjoYITMjCCEy4GCisGAQQBgjcDAwEx
# ghMeMIITGgYJKoZIhvcNAQcCoIITCzCCEwcCAQMxDzANBglghkgBZQMEAgEFADCC
# ATUGCyqGSIb3DQEJEAEEoIIBJASCASAwggEcAgEBBgorBgEEAYRZCgMBMDEwDQYJ
# YIZIAWUDBAIBBQAEIEajTCBl+W1vo2Rvu24bZlKUPszNbklFUEOFXoc9xV6BAgZU
# 70JeWd0YEzIwMTUwMzExMjEyMDU5LjU0MVowBwIBAYACAfSggbGkga4wgasxCzAJ
# BgNVBAYTAlVTMQswCQYDVQQIEwJXQTEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
# ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQLEwRNT1BSMScwJQYDVQQL
# Ex5uQ2lwaGVyIERTRSBFU046QzBGNC0zMDg2LURFRjgxJTAjBgNVBAMTHE1pY3Jv
# c29mdCBUaW1lLVN0YW1wIFNlcnZpY2Wggg69MIIGcTCCBFmgAwIBAgIKYQmBKgAA
# AAAAAjANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
# c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBD
# b3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUg
# QXV0aG9yaXR5IDIwMTAwHhcNMTAwNzAxMjEzNjU1WhcNMjUwNzAxMjE0NjU1WjB8
# MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
# bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1N
# aWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDCCASIwDQYJKoZIhvcNAQEBBQAD
# ggEPADCCAQoCggEBAKkdDbx3EYo6IOz8E5f1+n9plGt0VBDVpQoAgoX77XxoSyxf
# xcPlYcJ2tz5mK1vwFVMnBDEfQRsalR3OCROOfGEwWbEwRA/xYIiEVEMM1024OAiz
# Qt2TrNZzMFcmgqNFDdDq9UeBzb8kYDJYYEbyWEeGMoQedGFnkV+BVLHPk0ySwcSm
# XdFhE24oxhr5hoC732H8RsEnHSRnEnIaIYqvS2SJUGKxXf13Hz3wV3WsvYpCTUBR
# 0Q+cBj5nf/VmwAOWRH7v0Ev9buWayrGo8noqCjHw2k4GkbaICDXoeByw6ZnNPOcv
# RLqn9NxkvaQBwSAJk3jN/LzAyURdXhacAQVPIk0CAwEAAaOCAeYwggHiMBAGCSsG
# AQQBgjcVAQQDAgEAMB0GA1UdDgQWBBTVYzpcijGQ80N7fEYbxTNoWoVtVTAZBgkr
# BgEEAYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUw
# AwEB/zAfBgNVHSMEGDAWgBTV9lbLj+iiXGJo0T2UkFvXzpoYxDBWBgNVHR8ETzBN
# MEugSaBHhkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0
# cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcmwwWgYIKwYBBQUHAQEETjBMMEoG
# CCsGAQUFBzAChj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRzL01p
# Y1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNydDCBoAYDVR0gAQH/BIGVMIGSMIGPBgkr
# BgEEAYI3LgMwgYEwPQYIKwYBBQUHAgEWMWh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
# bS9QS0kvZG9jcy9DUFMvZGVmYXVsdC5odG0wQAYIKwYBBQUHAgIwNB4yIB0ATABl
# AGcAYQBsAF8AUABvAGwAaQBjAHkAXwBTAHQAYQB0AGUAbQBlAG4AdAAuIB0wDQYJ
# KoZIhvcNAQELBQADggIBAAfmiFEN4sbgmD+BcQM9naOhIW+z66bM9TG+zwXiqf76
# V20ZMLPCxWbJat/15/B4vceoniXj+bzta1RXCCtRgkQS+7lTjMz0YBKKdsxAQEGb
# 3FwX/1z5Xhc1mCRWS3TvQhDIr79/xn/yN31aPxzymXlKkVIArzgPF/UveYFl2am1
# a+THzvbKegBvSzBEJCI8z+0DpZaPWSm8tv0E4XCfMkon/VWvL/625Y4zu2JfmttX
# QOnxzplmkIz/amJ/3cVKC5Em4jnsGUpxY517IW3DnKOiPPp/fZZqkHimbdLhnPkd
# /DjYlPTGpQqWhqS9nhquBEKDuLWAmyI4ILUl5WTs9/S/fmNZJQ96LjlXdqJxqgaK
# D4kWumGnEcua2A5HmoDF0M2n0O99g/DhO3EJ3110mCIIYdqwUB5vvfHhAN/nMQek
# kzr3ZUd46PioSKv33nJ+YWtvd6mBy6cJrDm77MbL2IK0cs0d9LiFAR6A+xuJKlQ5
# slvayA1VmXqHczsI5pgt6o3gMy4SKfXAL1QnIffIrE7aKLixqduWsqdCosnPGUFN
# 4Ib5KpqjEWYw07t0MkvfY3v1mYovG8chr1m1rtxEPJdQcdeh0sVV42neV8HR3jDA
# /czmTfsNv11P6Z0eGTgvvM9YBS7vDaBQNdrvCScc1bN+NR4Iuto229Nfj950iEkS
# MIIE0jCCA7qgAwIBAgITMwAAAEw4Xaijk7XNmgAAAAAATDANBgkqhkiG9w0BAQsF
# ADB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
# UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQD
# Ex1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDAeFw0xNDA1MjMxNzIwMDda
# Fw0xNTA4MjMxNzIwMDdaMIGrMQswCQYDVQQGEwJVUzELMAkGA1UECBMCV0ExEDAO
# BgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEN
# MAsGA1UECxMETU9QUjEnMCUGA1UECxMebkNpcGhlciBEU0UgRVNOOkMwRjQtMzA4
# Ni1ERUY4MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNlMIIB
# IjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmqnCniGxGLbFMnSvB4KibldJ
# VqGe8oVaGsa3mm+uWGp9Jy4/1/gI6l/3MRm2H1DBkwygNPEFyz9gs0+hHfb3qlLM
# 4qvMdFV2Bwr5Vej6dsUp2S1JmUZ2+lxAnwd/Q4RjEgit3np6yEJT1FfTpPkeerPb
# aEp13Sh/A23KMkG53gm/xhv7BnN0I7R0mz08RzJ5uyzuVeFebq1bcqVNrbczhDH4
# s12Jhj6FgDDbEnXSDpuQ68/QN9mnRMl3zQ2LCNSOmIMh18PpcQnUgu22wUGCRPLr
# kkeP0/MsyhTlP0Dpr2n6XQVWkkUIvp1+y2FhqBX4nvvOT4RTR8DcyfHU/dX8BwID
# AQABo4IBGzCCARcwHQYDVR0OBBYEFHuYIoKgpikeP5mQnO9UAmN+e//GMB8GA1Ud
# IwQYMBaAFNVjOlyKMZDzQ3t8RhvFM2hahW1VMFYGA1UdHwRPME0wS6BJoEeGRWh0
# dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY1RpbVN0
# YVBDQV8yMDEwLTA3LTAxLmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKG
# Pmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWljVGltU3RhUENB
# XzIwMTAtMDctMDEuY3J0MAwGA1UdEwEB/wQCMAAwEwYDVR0lBAwwCgYIKwYBBQUH
# AwgwDQYJKoZIhvcNAQELBQADggEBAD/Awi40CGvtfHtSB2SJ2CYIYdgLxvNIpDI4
# v5hkAV4heCAELLybvEATAArQGsGUFG0lzaprgDOe17D6iGgqNfbmFaOALbhAI/if
# EHSW5Ny0IA4JI553xn2GoVkjOHzcS4pPDZ6/RYEKMQ2SdoagByhzXu3ANkgvq/71
# k7eWVLEH4tKcWf+6dkBsI6ME8Qc97kljFHtyNMT8mRByyzrnTCXBhU6MOZDii3l7
# zpFaG/dBq1pt9kbKPXrdv8HnipXnmeFTwTjjVa1abjcEAWJ1IDaHkaBTubMkXjrT
# eKzBpyhIt2NoHMT2W1hw3rIyNnBd6wmKzXHCfNC2TUap5+I2VZGhggNuMIICVgIB
# ATCB26GBsaSBrjCBqzELMAkGA1UEBhMCVVMxCzAJBgNVBAgTAldBMRAwDgYDVQQH
# EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xDTALBgNV
# BAsTBE1PUFIxJzAlBgNVBAsTHm5DaXBoZXIgRFNFIEVTTjpDMEY0LTMwODYtREVG
# ODElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZaIlCgEBMAkG
# BSsOAwIaBQADFQCp/m2JH3pxvrr5gAJbmc8v82BaHqCBwjCBv6SBvDCBuTELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjENMAsGA1UECxMETU9QUjEn
# MCUGA1UECxMebkNpcGhlciBOVFMgRVNOOjU3RjYtQzFFMC01NTRDMSswKQYDVQQD
# EyJNaWNyb3NvZnQgVGltZSBTb3VyY2UgTWFzdGVyIENsb2NrMA0GCSqGSIb3DQEB
# BQUAAgUA2Kqm+TAiGA8yMDE1MDMxMTExMzUyMVoYDzIwMTUwMzEyMTEzNTIxWjB0
# MDoGCisGAQQBhFkKBAExLDAqMAoCBQDYqqb5AgEAMAcCAQACAgszMAcCAQACAheD
# MAoCBQDYq/h5AgEAMDYGCisGAQQBhFkKBAIxKDAmMAwGCisGAQQBhFkKAwGgCjAI
# AgEAAgMW42ChCjAIAgEAAgMHoSAwDQYJKoZIhvcNAQEFBQADggEBAEaqu1SugPpa
# +NllKat/xgmMHIjwRg9vsqDBfQvJnjmqG2fGLa5O0fOB+e7hsX0tAfNt9FBZWgJY
# bH33S6SRRewswT2uTWvvFBB2rhD+IaRDCBfNR+Ma7SROfEB03wwh8N4WvYv+57tA
# r4AWMoXyjLjziHwGchiei4VDlHAUmjoqz7MOWB80cfP85FCXaJsRXcmSeOV6YRZu
# 6nwYacd6XOAsZRNEult91WbxlAy4Nxms79UuvhdB9La3AnMXQYcrb6T0G51Uemce
# 4zeltPIuuu+JvEvIPNT9tWYnbKb/hzzivjZO/c+QllD0Ul6cMzvQ2MxxwyowP//d
# fwFiJqcyXJkxggL1MIIC8QIBATCBkzB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMK
# V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
# IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0Eg
# MjAxMAITMwAAAEw4Xaijk7XNmgAAAAAATDANBglghkgBZQMEAgEFAKCCATIwGgYJ
# KoZIhvcNAQkDMQ0GCyqGSIb3DQEJEAEEMC8GCSqGSIb3DQEJBDEiBCAruu4vPDEG
# iMQhI/r63+ri6yo+B7T0jVXVsKOwwcvnbTCB4gYLKoZIhvcNAQkQAgwxgdIwgc8w
# gcwwgbEEFKn+bYkfenG+uvmAAluZzy/zYFoeMIGYMIGApH4wfDELMAkGA1UEBhMC
# VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
# BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRp
# bWUtU3RhbXAgUENBIDIwMTACEzMAAABMOF2oo5O1zZoAAAAAAEwwFgQU0UlLFh+g
# ko7HjUYAYSb4+vr+hZkwDQYJKoZIhvcNAQELBQAEggEAXZETodQ2Y/t99H9o2Lbu
# EICBS0a68nJHSdsWQwXpopTJQnNfMmGUkpdUS/9g86ORejjz/sXpHrwCRrl2ArgK
# iTIbF3ZqZB2xsCEdUKrNHfyALW/Wm/btsMBB/H2OPZbrqyGrr6D8ZrEZ+9ez/pNf
# RkGOqUe9hmbR6Ufy2j18ZaEDJux5XdP7TR+v+WnRSPF0ag5ij8V/fWYIlk3vdB0C
# UGOZ2TlkskZqILej7CoyZ7ua5Wbw2AvBi/URZWZ4BnPEttV8JbIsV+o0Xi6Cqw58
# sgHQdiE4xYO55pWk/cgqCobBMpcHujduk7TZt0hSLC6Rvr8uG91wOxX8gX/dFBIz
# 8A==
# SIG # End signature block
